/*  Power Station Industrializer
 *  Copyright (c) 2000 David A. Bartold
 *  Copyright (c) 2003-2020 Yury Aliaev
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _PSI_MAIN_H
#define _PSI_MAIN_H

#include <gtk/gtk.h>

#ifndef _
#if defined(ENABLE_NLS)
#  include <libintl.h>
#  define _(x) gettext(x)
#  ifdef gettext_noop
#    define N_(String) gettext_noop (String)
#  else
#    define N_(String) (String)
#  endif
#else
#  define N_(String) (String)
#  define _(x) (x)
#  define gettext(x) (x)
#endif
#endif

#include "xml-parser.h"

typedef struct
{
    const gchar* const description;
    gint (*activate)(const gint prate);
    gint (*open)(const gint prate);
    gint (*play)(gint16*, gint);
    void (*close)(void);
    void (*deactivate)(void);
    const gchar* (*err)(int);
    GtkWidget* (*get_config_widget)(void);
    void (*loadsettings)(void);
    void (*applysettings)(const gboolean);
} drv;

typedef enum
{
	PS_OBJECT_TUBE = 0,
	PS_OBJECT_ROD,
	PS_OBJECT_PLANE,
	PS_NUM_OBJECTS
} PSObjType;

typedef struct
{
    PSObjType obj_type;
    gboolean decay_is_used;
    gdouble decay_value;
    gint height, circum, length;
    gint plane_length, plane_width;
    gint innode, outnode;
    gdouble tenseness, speed, damping;
    gint actuation;
    gdouble velocity;
    gboolean stop;
    void (*percent_callback)(gfloat, gpointer);
} PSPhysMod;

extern drv *driver;
extern GSList *driver_list;
extern xmlpContext *config;

guint				psi_get_current_driver	(void);
void					psi_set_driver		(const guint driver,const  gint prate);
void                                    psi_driver_errmessage   (int err_no);

gint conf_subscribe_string(const gchar *path, const gchar *name, const gchar *deflt);
gchar* conf_get_string(gint tag);
void conf_set_string(gint tag, gchar *val);
gint conf_subscribe_string_array(const gchar *path, const gchar *name, const gchar *deflt);
GSList* conf_get_string_array(gint tag);
void conf_set_string_array(gint tag, GSList *val);
gint conf_subscribe_bool(const gchar *path, const gchar *name, const gboolean deflt);
gboolean conf_get_bool(gint tag);
void conf_set_bool(gint tag, gboolean val);
gint conf_subscribe_int(const gchar *path, const gchar *name, const gint deflt);
gint conf_get_int(gint tag);
void conf_set_int(gint tag, gint val);
void conf_change_path(const gint tag, const gchar *path);
void conf_rename(const gint tag, const gchar *name);

#endif
